colour.models.dataset.russell_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.russell_rgb Module

## Russell RGB Colourspace

Defines the Russell RGB colourspace:

- `RUSSELL_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.russellcottrell.com/photo/RussellRGB.htm (Last accessed 11 April 2014)

`colour.models.dataset.russell_rgb.` `RUSSELL_RGB_PRIMARIES` = array([[ 0.69, 0.31], [ 0.18, 0.77], [ 0.1 , 0.02]])

  Russell RGB colourspace primaries.

  RUSSELL_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.russell_rgb.` `RUSSELL_RGB_WHITEPOINT` = (0.33242, 0.34743)

  Russell RGB colourspace whitepoint.

  RUSSELL_RGB_WHITEPOINT : tuple

`colour.models.dataset.russell_rgb.` `RUSSELL_RGB_TO_XYZ_MATRIX` = array([[ 7.01572205e-01, 1.55416984e-01, 9.98078638e-02], [ 3.15199106e-01, 6.64839321e-01, 1.99615728e-02], [ 5.64421460e-17, 4.31713845e-02, 8.78309202e-01]])

  Russell RGB colourspace to CIE XYZ colourspace matrix.

  RUSSELL_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.russell_rgb.` `XYZ_TO_RUSSELL_RGB_MATRIX` = array([[ 1.58702529, -0.3598133 , -0.17216621], [-0.75351783, 1.67718484, 0.04750919], [ 0.03703754, -0.08243838, 1.13621599]])

  CIE XYZ colourspace to Russell RGB colourspace matrix.

  XYZ_TO_RUSSELL_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.russell_rgb.` `RUSSELL_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Russell RGB colourspace.

  RUSSELL_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.russell_rgb.` `RUSSELL_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Russell RGB colourspace to linear.

  RUSSELL_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.russell_rgb.` `RUSSELL_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e29310>

  Russell RGB colourspace.

  RUSSELL_RGB_COLOURSPACE : RGB_Colourspace